==> haskell-quickcheck-assertions-0.3.0-51-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-JNvUKfxTQN5L7KPD7NYv4H
key: quickcheck-assertions-0.3.0-JNvUKfxTQN5L7KPD7NYv4H
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: 4fc23cafb96d43a6864ac194d171252d
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-JNvUKfxTQN5L7KPD7NYv4H
depends:
    QuickCheck-2.12.6.1-FurF8Z9cNC7LPdADW0NOg6 base-4.12.0.0
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-quickcheck-assertions-0.3.0-53-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-quickcheck-assertions.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: quickcheck-assertions
version: 0.3.0
id: quickcheck-assertions-0.3.0-54cdlQjLJHI9FT2MrLXMUB
key: quickcheck-assertions-0.3.0-54cdlQjLJHI9FT2MrLXMUB
license: LGPL-3.0-only
maintainer: s9gf4ult@gmail.com
author: Aleksey Uymanov
homepage: https://github.com/s9gf4ult/quickcheck-assertions
synopsis: HUnit like assertions for QuickCheck
description:
    Library with convenient assertions for QuickCheck properties like in HUnit
category: Testing
abi: bdf3cc01d727b323d36b34ce21a51a97
exposed: True
exposed-modules:
    Test.QuickCheck.Assertions
import-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
library-dirs: /usr/lib/ghc-8.6.5/site-local/quickcheck-assertions-0.3.0
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/quickcheck-assertions-0.3.0
hs-libraries: HSquickcheck-assertions-0.3.0-54cdlQjLJHI9FT2MrLXMUB
depends:
    QuickCheck-2.13.1-NoI9FBLINF1hoOq3Jp2mP base-4.12.0.0
    ieee754-0.8.0-IfCS1Dp7pQVIOQRslM6kD
    pretty-show-1.9.5-4s9IVBWSe01IF3L4DDRCg8
haddock-interfaces: /usr/share/doc/haskell-quickcheck-assertions/html/quickcheck-assertions.haddock
haddock-html: /usr/share/doc/haskell-quickcheck-assertions/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
